# pontaria

# Usage
## Start a work shift
Use `pontaria start`, or `pontaria start "activity"` or `pontaria s` or `pontaria s "activity"`
## Commit a work shit
Use `pontaria commit`, or `pontaria commit "activity"` or `pontaria c` or `pontaria c "activity"`
## Analytics
Use `pontaria analytics` or `pontaria a`
